@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Vocabulary::Core;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Implementation of the JSON Schema Core vocabulary
 
-our $VERSION = '0.545';
+our $VERSION = '0.546';
 
 use 5.020;
 use Moo;
@@ -185,7 +185,7 @@ sub _eval_keyword_recursiveAnchor ($self, $data, $schema, $state) {
   return 1;
 }
 
-sub _traverse_keyword_dynamicAnchor { goto \&_traverse_keyword_anchor }
+sub _traverse_keyword_dynamicAnchor { shift->_traverse_keyword_anchor(@_) }
 
 # we already indexed the $dynamicAnchor uri, so there is nothing more to do at evaluation time.
 # we explicitly do NOT set $state->{initial_schema_uri}.
@@ -201,7 +201,7 @@ sub _eval_keyword_ref ($self, $data, $schema, $state) {
   $self->eval_subschema_at_uri($data, $schema, $state, $uri);
 }
 
-sub _traverse_keyword_recursiveRef { goto \&_traverse_keyword_ref }
+sub _traverse_keyword_recursiveRef { shift->_traverse_keyword_ref(@_) }
 
 sub _eval_keyword_recursiveRef ($self, $data, $schema, $state) {
   my $uri = Mojo::URL->new($schema->{'$recursiveRef'})->to_abs($state->{initial_schema_uri});
@@ -216,7 +216,7 @@ sub _eval_keyword_recursiveRef ($self, $data, $schema, $state) {
   return $self->eval_subschema_at_uri($data, $schema, $state, $uri);
 }
 
-sub _traverse_keyword_dynamicRef { goto \&_traverse_keyword_ref }
+sub _traverse_keyword_dynamicRef { shift->_traverse_keyword_ref(@_) }
 
 sub _eval_keyword_dynamicRef ($self, $data, $schema, $state) {
   my $uri = Mojo::URL->new($schema->{'$dynamicRef'})->to_abs($state->{initial_schema_uri});
@@ -347,7 +347,7 @@ JSON::Schema::Modern::Vocabulary::Core - Implementation of the JSON Schema Core
 
 =head1 VERSION
 
-version 0.545
+version 0.546
 
 =head1 DESCRIPTION
 
