@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Vocabulary::Validation;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Implementation of the JSON Schema Validation vocabulary
 
-our $VERSION = '0.545';
+our $VERSION = '0.546';
 
 use 5.020;
 use Moo;
@@ -125,7 +125,7 @@ sub _eval_keyword_multipleOf ($self, $data, $schema, $state) {
   return E($state, 'value is not a multiple of %s', sprintf_num($schema->{multipleOf}));
 }
 
-sub _traverse_keyword_maximum { goto \&_assert_number }
+sub _traverse_keyword_maximum { shift->_assert_number(@_) }
 
 sub _eval_keyword_maximum ($self, $data, $schema, $state) {
   return 1 if not is_type('number', $data);
@@ -133,7 +133,7 @@ sub _eval_keyword_maximum ($self, $data, $schema, $state) {
   return E($state, 'value is larger than %s', sprintf_num($schema->{maximum}));
 }
 
-sub _traverse_keyword_exclusiveMaximum { goto \&_assert_number }
+sub _traverse_keyword_exclusiveMaximum { shift->_assert_number(@_) }
 
 sub _eval_keyword_exclusiveMaximum ($self, $data, $schema, $state) {
   return 1 if not is_type('number', $data);
@@ -141,7 +141,7 @@ sub _eval_keyword_exclusiveMaximum ($self, $data, $schema, $state) {
   return E($state, 'value is equal to or larger than %s', sprintf_num($schema->{exclusiveMaximum}));
 }
 
-sub _traverse_keyword_minimum { goto \&_assert_number }
+sub _traverse_keyword_minimum { shift->_assert_number(@_) }
 
 sub _eval_keyword_minimum ($self, $data, $schema, $state) {
   return 1 if not is_type('number', $data);
@@ -149,7 +149,7 @@ sub _eval_keyword_minimum ($self, $data, $schema, $state) {
   return E($state, 'value is smaller than %s', sprintf_num($schema->{minimum}));
 }
 
-sub _traverse_keyword_exclusiveMinimum { goto \&_assert_number }
+sub _traverse_keyword_exclusiveMinimum { shift->_assert_number(@_) }
 
 sub _eval_keyword_exclusiveMinimum ($self, $data, $schema, $state) {
   return 1 if not is_type('number', $data);
@@ -157,7 +157,7 @@ sub _eval_keyword_exclusiveMinimum ($self, $data, $schema, $state) {
   return E($state, 'value is equal to or smaller than %s', sprintf_num($schema->{exclusiveMinimum}));
 }
 
-sub _traverse_keyword_maxLength { goto \&_assert_non_negative_integer }
+sub _traverse_keyword_maxLength { shift->_assert_non_negative_integer(@_) }
 
 sub _eval_keyword_maxLength ($self, $data, $schema, $state) {
   return 1 if not is_type('string', $data);
@@ -165,7 +165,7 @@ sub _eval_keyword_maxLength ($self, $data, $schema, $state) {
   return E($state, 'length is greater than %d', $schema->{maxLength});
 }
 
-sub _traverse_keyword_minLength { goto \&_assert_non_negative_integer }
+sub _traverse_keyword_minLength { shift->_assert_non_negative_integer(@_) }
 
 sub _eval_keyword_minLength ($self, $data, $schema, $state) {
 
@@ -187,7 +187,7 @@ sub _eval_keyword_pattern ($self, $data, $schema, $state) {
   return E($state, 'pattern does not match');
 }
 
-sub _traverse_keyword_maxItems { goto \&_assert_non_negative_integer }
+sub _traverse_keyword_maxItems { shift->_assert_non_negative_integer(@_) }
 
 sub _eval_keyword_maxItems ($self, $data, $schema, $state) {
   return 1 if not is_type('array', $data);
@@ -195,7 +195,7 @@ sub _eval_keyword_maxItems ($self, $data, $schema, $state) {
   return E($state, 'more than %d item%s', $schema->{maxItems}, $schema->{maxItems} > 1 ? 's' : '');
 }
 
-sub _traverse_keyword_minItems { goto \&_assert_non_negative_integer }
+sub _traverse_keyword_minItems { shift->_assert_non_negative_integer(@_) }
 
 sub _eval_keyword_minItems ($self, $data, $schema, $state) {
   return 1 if not is_type('array', $data);
@@ -216,7 +216,7 @@ sub _eval_keyword_uniqueItems ($self, $data, $schema, $state) {
 }
 
 # Note: no effort is made to check if the 'contains' keyword has been disabled via its vocabulary.
-sub _traverse_keyword_maxContains { goto \&_assert_non_negative_integer }
+sub _traverse_keyword_maxContains { shift->_assert_non_negative_integer(@_) }
 
 sub _eval_keyword_maxContains ($self, $data, $schema, $state) {
   return 1 if not exists $state->{_num_contains};
@@ -228,7 +228,7 @@ sub _eval_keyword_maxContains ($self, $data, $schema, $state) {
   return 1;
 }
 
-sub _traverse_keyword_minContains { goto \&_assert_non_negative_integer }
+sub _traverse_keyword_minContains { shift->_assert_non_negative_integer(@_) }
 
 sub _eval_keyword_minContains ($self, $data, $schema, $state) {
   return 1 if not exists $state->{_num_contains};
@@ -240,7 +240,7 @@ sub _eval_keyword_minContains ($self, $data, $schema, $state) {
   return 1;
 }
 
-sub _traverse_keyword_maxProperties { goto \&_assert_non_negative_integer }
+sub _traverse_keyword_maxProperties { shift->_assert_non_negative_integer(@_) }
 
 sub _eval_keyword_maxProperties ($self, $data, $schema, $state) {
   return 1 if not is_type('object', $data);
@@ -249,7 +249,7 @@ sub _eval_keyword_maxProperties ($self, $data, $schema, $state) {
     $schema->{maxProperties} > 1 ? 'ies' : 'y');
 }
 
-sub _traverse_keyword_minProperties { goto \&_assert_non_negative_integer }
+sub _traverse_keyword_minProperties { shift->_assert_non_negative_integer(@_) }
 
 sub _eval_keyword_minProperties ($self, $data, $schema, $state) {
   return 1 if not is_type('object', $data);
@@ -336,7 +336,7 @@ JSON::Schema::Modern::Vocabulary::Validation - Implementation of the JSON Schema
 
 =head1 VERSION
 
-version 0.545
+version 0.546
 
 =head1 DESCRIPTION
 
